Package 'lavaan.shiny'

Title: Latent Variable Analysis with Shiny
Description: Interactive shiny application for working with different kinds of latent variable analysis, with the 'lavaan' package. Graphical output for models are provided and different estimators are supported.
Authors: William Kyle Hamilton <[email protected]>
Maintainer: William Kyle Hamilton <[email protected]>
License: GPL-3
Version: 1.0
Built: 2026-05-12 07:42:28 UTC
Source: https://github.com/kylehamilton/lavaan.shiny

Help Index


Launch lavaan.shiny User Interface

Description

lavaan.shiny() loads interactive user interface built using R shiny.

Usage

lavaan.shiny()

Details

Start lavaan.shiny

The interactive user interface is to provide an easy way for people who are learning how to work with the lavaan package and/or are not comfortable with the R command line system. Includes example data for testing out a few example analysis.

Value

Nothing

Examples

## Not run: 
library(shiny)
lavaan.shiny()

## End(Not run)