Welcome to ClientVPS Mirrors

Help for package lavaan.shiny
Type: Package
Title: Latent Variable Analysis with Shiny
Version: 1.2
Date: 2017-04-06
Author: W. Kyle Hamilton <kyle.hamilton@gmail.com>
Maintainer: W. Kyle Hamilton <kyle.hamilton@gmail.com>
Description: Interactive shiny application for working with different kinds of latent variable analysis, with the 'lavaan' package. Graphical output for models are provided and different estimators are supported.
License: GPL-3
URL: https://github.com/kylehamilton/lavaan.shiny
Depends: R (≥ 3.0.3)
Imports: shiny, shinyAce, psych, lavaan, semPlot
LazyData: TRUE
RoxygenNote: 5.0.1
NeedsCompilation: no
Packaged: 2017-04-07 01:05:26 UTC; hcilab
Repository: CRAN
Date/Publication: 2017-04-07 06:05:09 UTC

Launch lavaan.shiny User Interface

Description

lavaan.shiny() loads interactive user interface built using R shiny.

Usage

lavaan.shiny()

Details

Start lavaan.shiny

The interactive user interface is to provide an easy way for people who are learning how to work with the lavaan package and/or are not comfortable with the R command line system. Includes example data for testing out a few example analysis.

Value

Nothing

Examples

## Not run: 
library(shiny)
lavaan.shiny()

## End(Not run)

Need a high-speed mirror for your open-source project?
Contact our mirror admin team at info@clientvps.com.

This archive is provided as a free public service to the community.
Proudly supported by infrastructure from VPSPulse , RxServers , BuyNumber , UnitVPS , OffshoreName and secure payment technology by ArionPay.